ternary_pl: Data structure with the projected and boundary by node and...

Description Usage Arguments Value Examples

Description

Data structure with the projected and boundary by node and class.

Usage

1
ternary_pl(dat, dx, dy)

Arguments

dat

data.frame

dx

first direction included in id

dy

second direction included in id

Value

ternary plot

Examples

1
2
3
4
5
#crab data set with all the observations used as training
pprf.crab <- PPforest::PPforest(data = crab, std =TRUE, class = "Type",
 size.tr = 1, m = 100, size.p = .5, PPmethod = 'LDA')
 st <- ternary_str(pprf.crab, id = c(1, 2, 3), sp = 3, dx = 1, dy = 2)
 ternary_pl(st, dx =1, dy = 2)

natydasilva/shineforest documentation built on May 9, 2019, 5:55 a.m.