ternary_str: Data structure with the projected and boundary by node and...

Description Usage Arguments Value Examples

Description

Data structure with the projected and boundary by node and class.

Usage

1
ternary_str(ppf, id, sp, dx, dy)

Arguments

ppf

is a PPforest object

id

is a vector with the selected projection directions

sp

is the simplex dimensions, if k is the number of classes sp = k - 1

dx

first direction included in id

dy

second direction included in id

Value

Data frame needed to visualize a ternary plot

Examples

1
2
3
4
#crab data set with all the observations used as training
pprf.crab <- PPforest::PPforest(data = crab, std =TRUE, class = "Type",
 size.tr = 1, m = 100, size.p = .5, PPmethod = 'LDA')
str(ternary_str(pprf.crab, id = c(1, 2, 3), sp = 3, dx = 1, dy = 2) )

natydasilva/shineforest documentation built on May 9, 2019, 5:55 a.m.