Description Usage Arguments Value Examples
Data structure with the projected and boundary by node and class.
1 | ternary_str(ppf, id, sp, dx, dy)
|
ppf |
is a PPforest object |
id |
is a vector with the selected projection directions |
sp |
is the simplex dimensions, if k is the number of classes sp = k - 1 |
dx |
first direction included in id |
dy |
second direction included in id |
Data frame needed to visualize a ternary plot
1 2 3 4 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.